{"": "", "Total": "Spolu", "Up one level": "O \u00farove\u0148 vy\u0161\u0161ie", "File name": "N\u00e1zov s\u00faboru", "Write to the filesystem": "", "All combined": "V\u0161etko kombinovan\u00e9", "Select this directory": "Vyberte tento adres\u00e1r", "File transfer": "Prenos s\u00faborov", "Filesystem": "", "Cancel": "Zru\u0161i\u0165", "Disk space": "Miesto na disku", "Save": "Ulo\u017ei\u0165", "Deleting": "", "Read from the filesystem": ""}