{"": "", "Total": "Jumlah", "Up one level": "Naik satu tingkat", "File name": "Nama berkas", "Write to the filesystem": "Menulis ke sistem berkas", "All combined": "Semua dikombinasikan", "Select this directory": "Pilih direktori ini", "File transfer": "Transfer berkas", "Filesystem": "Sistem berkas", "Cancel": "Batal", "Disk space": "Ruang Kandar", "Save": "Simpan", "Deleting": "Menghapus", "Read from the filesystem": "Membaca dari sistem berkas"}