{"": "", "Total": "Yhteens\u00e4", "Up one level": "Yksi taso yl\u00f6sp\u00e4in", "File name": "Tiedostonimi", "Write to the filesystem": "Kirjoittaa tiedostoj\u00e4rjestelm\u00e4\u00e4n", "All combined": "", "Select this directory": "Valitse t\u00e4m\u00e4 hakemisto", "File transfer": "", "Filesystem": "Tiedostoj\u00e4rjestelm\u00e4", "Cancel": "Peruuta", "Disk space": "Levytila", "Save": "Tallenna", "Deleting": "Poistetaan", "Read from the filesystem": "Lue tiedostoj\u00e4rjestelm\u00e4st\u00e4"}